import { Component, OnInit, ViewChild } from '@angular/core';
import { ReactiveFormsModule } from '@angular/forms';
import { HttpClient } from '@angular/common/http';
import { Router } from '@angular/router';
import { catchError } from 'rxjs/operators';
import {
  FormControl,
  FormGroup,
  NonNullableFormBuilder,
  Validators,
} from '@angular/forms';
import { CommonCompModule } from '../common.modules';
import { textbookServer } from '../../../services/textbook';
import { AuthServr } from '../../../services/auth.service';
import { CaptchaComponent } from '../../../app/captcha/captcha.component';
import { NzMessageService } from 'ng-zorro-antd/message';
import Parse from 'parse';
@Component({
  selector: 'app-account-info',
  standalone: true,
  imports: [ReactiveFormsModule, CommonCompModule, CaptchaComponent],
  templateUrl: './account-info.component.html',
  styleUrls: ['./account-info.component.scss'],
})
export class AccountInfoComponent implements OnInit {
  validateForm: FormGroup<{
    name: FormControl<string>;//姓名
    mobile: FormControl<string>;//手机号
    email: FormControl<string>;//电子邮箱
    workPhone: FormControl<string>;//公共电话
    province: FormControl<string>;//省份
    unitType: FormControl<string>;//单位类型
    unit: FormControl<string>;//单位名称
    department: FormControl<string>;//所在部门
    job: FormControl<string>;//职务
    idcard: FormControl<string>;//身份证号
    identity: FormControl<string>;//用户类型
    file: FormControl<string>; //单位联系人认证文件
  }> = this.fb.group({
    name: ['', [Validators.required]],
    mobile: ['', [Validators.required]],
    email: ['', [Validators.required]],
    workPhone: ['', [Validators.required]],
    province: ['', [Validators.required]],
    unitType: ['', [Validators.required]],
    unit: ['', [Validators.required]],
    department: ['', [Validators.required]],
    job: ['', [Validators.required]],
    idcard: ['', [Validators.required]],
    identity: ['', [Validators.required]],
    file: ['', [Validators.required]],
  });
  constructor(
    public tbookSer: textbookServer,
    private fb: NonNullableFormBuilder,
    public router: Router,
    private authServr: AuthServr,
    private message: NzMessageService,
    private http: HttpClient
  ) {}

  ngOnInit() {}
  submitForm(): void {
    if (this.validateForm.valid) {
      let { name } = this.validateForm.value;
    } else {
      this.message.warning('请填写完整的信息');
      Object.values(this.validateForm.controls).forEach((control) => {
        if (control.invalid) {
          control.markAsDirty();
          control.updateValueAndValidity({ onlySelf: true });
        }
      });
    }
  }
}
