import { Injectable } from "@angular/core";
import Parse from "parse";
import { Router } from "@angular/router";
import { textbookServer } from './textbook'
import { Authing } from '@authing/browser';
import { LoginState } from "@authing/browser/dist/types/global";

@Injectable({
  providedIn: "root",
})
export class AuthServr {
  isLoggedIn = false;
  countdown: number = 60; //登录时验证码倒计时
  regcountdown: number = 60; //注册验证码倒计时
  resetcountdown: number = 60; //重置密码验证码倒计时
  redirectUrl: string = '';
  roterPath: Array<any> = [
    {
      name: '国家级管理员',
      type: 1,
      route: '/nav-admin',
    },
    {
      name: '省级教育行政部门',
      type: 2,
      route: '/nav-province-submit',
    },
    {
      name: '流程管理员登录',
      type: 3,
      route: '/nav-province-contact',
    },
    {
      name: '省属高校联系人',
      type: 4,
      route: '/nav-province-school-contact',
    },
    {
      name: '教材评审组成员',
      type: 5,
      route: '/nav-review',
    },
    {
      name: '作者/教师/主编',
      type: 6,
      route:'/nav-author/manage/space'
    },
  ];

  authingSDK:Authing
  constructor(public router: Router,private textbook:textbookServer) {
     
    this.authingSDK = new Authing({
      domain: 'https://textbook.u2-dev.hep.com.cn', // 应用的认证地址
      appId: '6682ab96b7bd5db59d6785a0',// 应用 ID
      redirectUri: location.origin,// 登录回调地址
    });


  }

  /** Authing云Login */
  loginState: LoginState | null = null;
  // 以跳转方式打开 Authing 托管的登录页
  loginAuthing(){
    this.authingSDK.loginWithRedirect();
  }
  // 获取用户的登录状态
  async getLoginState() {
    try {
      const state = await this.authingSDK.getLoginState();
      this.loginState = state;
      console.log(this.loginState)
    } catch(error) {
      console.log(error);
    }
  }

  /** Parse传统Login */
  login(username:any, password:any, company:string) {
    return new Promise(async (resolve, reject) => {
      let a = /^1[3456789]\d{9}$/;
      //如果是手机号登录，获取对应的mobile
      if (String(username).match(a)) {
        let query = new Parse.Query("_User");
        query.equalTo("company", company);
        query.equalTo("mobile", username);
        let res = await query.first();
        if (res?.id) {
          username = res.get("username");
        } else {
          reject({ message: "用户不存在" });
          return;
        }
      }
      Parse.User.logIn(username, password)
        .then(async (data:any) => {
          // await this.developerSer.authDevCompany(); //更新开发者信息
          console.log(data);
          localStorage.setItem('profile',JSON.stringify({type:'navAuthor'}))
          this.textbook.profile = {type:'navAuthor'}
          this.router.navigate([this.roterPath[5].route]);
          resolve(data);
        })
        .catch((err:any) => {
          console.log(err.message);
          if (err.message.indexOf("Invalid username/password.") != -1) {
            reject({ message: "用户名或密码不正确" });
          } else {
            reject({ message: "用户名或密码不正确" });
          }
        });
    });
  }

  logout(): void {
    Parse.User.logOut().then((user) => {
      // this.developerSer.companyId = ''
      window.localStorage.clear()
      this.router.navigate(["/user/login"]);
    });
  }

}
